==> haskell-wherefrom-compat-0.1.1.1-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wherefrom-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wherefrom-compat
version:              0.1.1.1
visibility:           public
id:                   wherefrom-compat-0.1.1.1-9IQIJUn2DUXENcXRtvYPTF
key:                  wherefrom-compat-0.1.1.1-9IQIJUn2DUXENcXRtvYPTF
license:              BSD-2-Clause
copyright:            The wherefrom-compat contributors
maintainer:           teofilcamarasu@gmail.com
author:               Teo Camarasu
synopsis:             A compatibility layer for GHC'\''s '\''wherefrom'\'' function
description:
    A compatibility layer for GHC'\''s '\''wherefrom'\'' function,
    which exposes info provenance information.
    Each major version of this library exports 
    a different version of this interface.

category:             Compatibility
abi:                  30bf861d7ad1ebbc5b8f11c82e0fca17
exposed:              True
exposed-modules:      GHC.InfoProv.Compat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wherefrom-compat-0.1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wherefrom-compat-0.1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wherefrom-compat-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wherefrom-compat
hs-libraries:         HSwherefrom-compat-0.1.1.1-9IQIJUn2DUXENcXRtvYPTF
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-wherefrom-compat/html/wherefrom-compat.haddock

haddock-html:         /usr/share/doc/haskell-wherefrom-compat/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wherefrom-compat-0.1.1.1-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wherefrom-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wherefrom-compat
version:              0.1.1.1
visibility:           public
id:                   wherefrom-compat-0.1.1.1-LNe2t2Qiv47LdICJ81Lp82
key:                  wherefrom-compat-0.1.1.1-LNe2t2Qiv47LdICJ81Lp82
license:              BSD-2-Clause
copyright:            The wherefrom-compat contributors
maintainer:           teofilcamarasu@gmail.com
author:               Teo Camarasu
synopsis:             A compatibility layer for GHC'\''s '\''wherefrom'\'' function
description:
    A compatibility layer for GHC'\''s '\''wherefrom'\'' function,
    which exposes info provenance information.
    Each major version of this library exports 
    a different version of this interface.

category:             Compatibility
abi:                  7818bdad4056fbf61c5e68c8c0f3acd1
exposed:              True
exposed-modules:      GHC.InfoProv.Compat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wherefrom-compat-0.1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wherefrom-compat-0.1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wherefrom-compat-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wherefrom-compat
hs-libraries:         HSwherefrom-compat-0.1.1.1-LNe2t2Qiv47LdICJ81Lp82
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-wherefrom-compat/html/wherefrom-compat.haddock

haddock-html:         /usr/share/doc/haskell-wherefrom-compat/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
